@@ -1,17 +1,46 @@
-/* Copyright (C) 2000  Free Software Foundation
+/* Copyright (C) 1999, 2000, 2002  Free Software Foundation
 
-   This file is part of libgcj.
+This file is part of GNU Classpath.
+
+GNU Classpath is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2, or (at your option)
+any later version.
+
+GNU Classpath is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with GNU Classpath; see the file COPYING.  If not, write to the
+Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+02111-1307 USA.
+
+Linking this library statically or dynamically with other modules is
+making a combined work based on this library.  Thus, the terms and
+conditions of the GNU General Public License cover the whole
+combination.
+
+As a special exception, the copyright holders of this library give you
+permission to link this library with independent modules to produce an
+executable, regardless of the license terms of these independent
+modules, and to copy and distribute the resulting executable under
+terms of your choice, provided that you also meet, for each linked
+independent module, the terms and conditions of the license of that
+module.  An independent module is a module which is not derived from
+or based on this library.  If you modify this library, you may extend
+this exception to your version of the library, but you are not
+obligated to do so.  If you do not wish to do so, delete this
+exception statement from your version. */
 
-This software is copyrighted work licensed under the terms of the
-Libgcj License.  Please consult the file "LIBGCJ_LICENSE" for
-details.  */
 
 package java.awt.image;
 
 import java.awt.Point;
 import java.awt.Transparency;
 import java.awt.color.ColorSpace;
-import gnu.gcj.awt.Buffers;
+import gnu.java.awt.Buffers;
 
 /**
  * A color model operates with colors in several formats:
@@ -39,7 +68,7 @@ import gnu.gcj.awt.Buffers;
  * <li>arrays of unnormalized component samples of single pixel: these
  * samples are scaled and multiplied according to the color model, but
  * is otherwise not packed or encoded. Each element of the array is one
- * seperate component sample. The color model only operate on the
+ * separate component sample. The color model only operate on the
  * components from one pixel at a time, but using offsets, allows
  * manipulation of arrays that contain the components of more than one
  * pixel.</li>
@@ -47,8 +76,8 @@ import gnu.gcj.awt.Buffers;
  * </ul>
  *
  * @author Rolf W. Rasmussen <rolfwr@ii.uib.no>
+ * @author C. Brian Jones (cbj@gnu.org) 
  */
-
 public abstract class ColorModel implements Transparency
 {
   protected int pixel_bits;
@@ -74,6 +103,12 @@ public abstract class ColorModel implements Transparency
     return array;
   } 
 
+  /**
+   * Constructs the default color model.  The default color model 
+   * can be obtained by calling <code>getRGBdefault</code> of this
+   * class.
+   * @param b the number of bits wide used for bit size of pixel values
+   */
   public ColorModel(int bits)
   {
     this(bits * 4, // total bits, sRGB, four channels
@@ -85,10 +120,32 @@ public abstract class ColorModel implements Transparency
 	 Buffers.smallestAppropriateTransferType(bits * 4));
   }
 
+  /**
+   * Constructs a ColorModel that translates pixel values to
+   * color/alpha components.
+   *
+   * @exception IllegalArgumentException If the length of the bit array is less
+   * than the number of color or alpha components in this ColorModel, or if the
+   * transparency is not a valid value, or if the sum of the number of bits in
+   * bits is less than 1 or if any of the elements in bits is less than 0.
+   */
   protected ColorModel(int pixel_bits, int[] bits, ColorSpace cspace,
 		       boolean hasAlpha, boolean isAlphaPremultiplied,
 		       int transparency, int transferType)
   {
+    int bits_sum = 0;
+    for (int i = 0; i < bits.length; i++)
+      {
+        if (bits [i] < 0)
+          throw new IllegalArgumentException ();
+
+        bits_sum |= bits [i];
+      }
+    
+    if ((bits.length < cspace.numComponents)
+        || (bits_sum < 1))
+      throw new IllegalArgumentException ();
+
     this.pixel_bits = pixel_bits;
     this.bits = bits;
     this.cspace = cspace;
@@ -98,6 +155,10 @@ public abstract class ColorModel implements Transparency
     this.transferType = transferType;
   }
 
+  /**
+   * Returns the default color model which in Sun's case is an instance
+   * of <code>DirectColorModel</code>.
+   */
   public static ColorModel getRGBdefault()
   {
     return new DirectColorModel(8, 0xff0000, 0xff00, 0xff, 0xff000000);
@@ -113,6 +174,9 @@ public abstract class ColorModel implements Transparency
     return isAlphaPremultiplied;
   }
 
+  /**
+   * Get get number of bits wide used for the bit size of pixel values
+   */
   public int getPixelSize()
   {
     return pixel_bits;
@@ -251,7 +315,7 @@ public abstract class ColorModel implements Transparency
    * @see #getRed(Object)
    */
   public int getAlpha(Object inData) {
-    return getBlue(getPixelFromArray(inData));
+    return getAlpha(getPixelFromArray(inData));
   }
 
   /**
@@ -337,7 +401,7 @@ public abstract class ColorModel implements Transparency
    * @return arrays of unnormalized component samples of single
    * pixel.  The scale and multiplication state of the samples are
    * according to the color model. Each component sample is stored
-   * as a seperate element in the array.
+   * as a separate element in the array.
    */
   public int[] getComponents(int pixel, int[] components, int offset) {
     // FIXME: implement
@@ -358,7 +422,7 @@ public abstract class ColorModel implements Transparency
    * @return arrays of unnormalized component samples of single
    * pixel.  The scale and multiplication state of the samples are
    * according to the color model. Each component sample is stored
-   * as a seperate element in the array.
+   * as a separate element in the array.
    */
   public int[] getComponents(Object pixel, int[] components, int offset)
   {
@@ -382,7 +446,7 @@ public abstract class ColorModel implements Transparency
     for (int i=0; i<numComponents; i++)
     {
       float in = normComponents[normOffset++];
-      int out = (int) (in * ((2<<getComponentSize(i)) - 1));
+      int out = (int) (in * ((1<<getComponentSize(i)) - 1));
       components[offset++] = out;
     }
     return components;
@@ -405,7 +469,7 @@ public abstract class ColorModel implements Transparency
     for (int i=0; i<numComponents; i++)
     {
       float in = components[offset++];
-      float out = in / ((2<<getComponentSize(i)) - 1);
+      float out = in / ((1<<getComponentSize(i)) - 1);
       normComponents[normOffset++] = out;
     }
     return normComponents;
@@ -429,7 +493,7 @@ public abstract class ColorModel implements Transparency
    * @param arrays of unnormalized component samples of single
    * pixel.  The scale and multiplication state of the samples are
    * according to the color model. Each component sample is stored
-   * as a seperate element in the array.
+   * as a separate element in the array.
    *
    * @return pixel value encoded according to the color model.
    */
@@ -525,7 +589,8 @@ public abstract class ColorModel implements Transparency
     return sm.getTransferType() == transferType;
   }
 
-  public void finalize() {
+  public void finalize()
+  {
   }
 
   /**
